import { IConfiguration } from '../types';
import { Base } from './base';
/**
 * Manages the configuration settings for the xpanderAI client.
 *
 * This class encapsulates settings such as the API key, base URL,
 * metrics reporting, and optional organization-specific parameters.
 */
export declare class Configuration extends Base {
    /** API key for authenticating requests to xpanderAI. */
    apiKey: string;
    /** Base URL for the xpanderAI API requests. */
    baseUrl: string;
    /** Flag to enable or disable metrics reporting. */
    withMetricsReport: boolean;
    /** Optional organization ID for scoped API requests. */
    organizationId?: string;
    /**
     * Constructs a new Configuration instance.
     *
     * @param apiKey - The API key for xpanderAI.
     * @param baseUrl - The base URL for API requests (defaults to `DEFAULT_BASE_URL`).
     * @param withMetricsReport - Whether to enable metrics reporting (defaults to `false`).
     * @param organizationId - Optional organization ID for additional scoping.
     */
    constructor({ apiKey, baseUrl, withMetricsReport, organizationId, }: IConfiguration);
    /**
     * Constructs the full API endpoint URL.
     *
     * The URL combines the base URL with the optional organization ID if provided.
     *
     * @returns The constructed API endpoint URL.
     */
    get url(): string;
}
