import { AgentGraphItemType, IAgentGraphItemSettings } from '../../types';
import { Agent } from '../agents';
import { Base } from '../base';
/**
 * Represents a single item (node) in an agent's graph structure.
 *
 * @class GraphItem
 * @extends {Base}
 *
 * @param {Agent} agent - The agent associated with this graph item.
 * @param {string} id - The unique identifier for the graph item.
 * @param {string} itemId - The associated item ID of the graph item.
 * @param {string} name - The name of the graph item.
 * @param {AgentGraphItemType} type - The type of the graph item (e.g., TOOL or AGENT).
 * @param {boolean} isLocalTool - Indicates if the graph item is a local tool.
 * @param {string[]} targets - The list of target node IDs connected to this graph item.
 * @param {IAgentGraphItemSettings} [settings] - Additional settings for the graph item.
 *
 * @memberof xpander.ai
 */
export declare class GraphItem extends Base {
    private agent;
    id: string;
    itemId: string;
    name: string;
    type: AgentGraphItemType;
    isLocalTool: boolean;
    targets: string[];
    settings?: IAgentGraphItemSettings | undefined;
    constructor(agent: Agent, id?: string, itemId?: string, name?: string, type?: AgentGraphItemType, isLocalTool?: boolean, targets?: string[], settings?: IAgentGraphItemSettings | undefined);
    /**
     * Saves the current graph item state to the server.
     *
     * @returns {GraphItem} The updated graph item after saving.
     * @throws {Error} If saving the graph item fails.
     */
    save(): GraphItem;
    /**
     * Connects this graph item to other graph items, creating edges in the graph.
     *
     * @param {GraphItem[]} targets - The target graph items to connect to.
     * @returns {GraphItem} The updated graph item after establishing connections.
     */
    connect(targets: GraphItem[]): GraphItem;
}
